.. include:: ../BADGES.rst

Python API Function Summary
===========================

.. autosummary::
    :toctree: _function_autosummary

    hspfbintoolbox.hspfbintoolbox.about
    hspfbintoolbox.hspfbintoolbox.catalog
    hspfbintoolbox.hspfbintoolbox.extract
